@@ -5,6 +5,7 @@ from functools import wraps
 
 from .constants import Status
 from .flow import CloudFlow, _terminate_flow_simplified
+from .helper import prepare_flow_model_for_render
 
 
 def asyncify(f):
@@ -45,6 +46,7 @@ async def status(args):
                 f'[red]Something went wrong while fetching the details for {args.flow} ![/red]. Please retry after sometime.'
             )
         else:
+            prepare_flow_model_for_render(_result)
             for k, v in _result.items():
                 if k == 'yaml' and v is not None:
                     v = Syntax(
@@ -203,28 +205,25 @@ async def _remove_multi(flow_id_list):
         print(f'Successfully removed flows listed above.')
 
 
-@asyncify
-async def logs(args):
-    from .flow import pb_task, pbar
+def logs(args):
+    from rich import print
 
-    with pbar:
-        pbar.start_task(pb_task)
-        pbar.update(
-            pb_task,
-            total=1,
-            description=f'Press Ctrl-C to quit',
-            title=f'Live streaming from {args.flow}',
-        )
-        _params = {'flow_id': args.flow}
-        if args.executor is not None:
-            _params['executor'] = args.executor
-        await CloudFlow.logstream(_params)
+    print("[red]'jc logs' command will be deprecated soon![/red]")
+    print(
+        f"Please visit https://dashboard.wolf.jina.ai/flow/{args.flow} for Flow logs instead.\nThis link can also be found at the bottom of the output from 'jc status'."
+    )
 
 
 def login(args):
-    from auth.api import login
+    import hubble
 
-    login(args)
+    hubble.login()
+
+
+def logout(args):
+    import hubble
+
+    hubble.logout()
 
 
 def new(args):
