@@ -8,7 +8,6 @@ import tempfile
 import threading
 import warnings
 from contextlib import contextmanager
-from packaging.version import Version
 from pathlib import Path
 from typing import Dict, Union
 from urllib.parse import urlparse
@@ -16,6 +15,7 @@ from urllib.request import Request, urlopen
 
 import pkg_resources
 import yaml
+from packaging.version import Version
 from rich import print
 from rich.highlighter import ReprHighlighter
 from rich.panel import Panel
@@ -76,6 +76,8 @@ def get_logger(name='jcloud'):
     logger = logging.getLogger(name)
     logger.setLevel(os.environ.get('JCLOUD_LOGLEVEL', 'INFO'))
 
+    if logger.hasHandlers():
+        logger.handlers.clear()
     rich_handler = RichHandler(rich_tracebacks=True)
     formatter = logging.Formatter('%(message)s')
     rich_handler.setFormatter(formatter)
@@ -166,6 +168,7 @@ def valid_uri(uses):
             'docker',
             'jinahub+docker',
             'jinahub+sandbox',
+            'jinahub+serverless',
             'jinahub',
         )
     except Exception:
@@ -195,3 +198,21 @@ class CustomHighlighter(ReprHighlighter):
     highlights = ReprHighlighter.highlights + [
         r"(?P<url>(grpc|grpcs)://[-0-9a-zA-Z$_+!`(),.?/;:&=%#]*)"
     ]
+
+
+def remove_prefix(s: str, prefix: str):
+    return s[len(prefix) :] if s.startswith(prefix) else s
+
+
+def prepare_flow_model_for_render(response: Dict) -> None:
+    # 'gateway' and 'endpoints' should be mutually exclusive.
+    if response['gateway']:
+        del response['endpoints']
+    elif response['endpoints']:
+        del response['gateway']
+
+    # Extra handle for 'dashboards' key; the value is a map
+    # but since we only have monitoring dashboard at the moment,
+    # for simplicity we turn the map to a string for display purpose.
+    if response['dashboards']:
+        response['dashboards'] = response['dashboards']['monitoring']
